@@ -30,20 +30,20 @@ import (
 	"k8s.io/apimachinery/pkg/util/intstr"
 
 	network "knative.dev/networking/pkg"
-	"knative.dev/networking/pkg/apis/networking"
 	"knative.dev/pkg/kmeta"
 	"knative.dev/pkg/metrics"
-	_ "knative.dev/pkg/metrics/testing"
 	"knative.dev/pkg/ptr"
 	"knative.dev/pkg/system"
-	_ "knative.dev/pkg/system/testing"
 	"knative.dev/serving/pkg/apis/autoscaling"
+	apicfg "knative.dev/serving/pkg/apis/config"
 	"knative.dev/serving/pkg/apis/serving"
 	v1 "knative.dev/serving/pkg/apis/serving/v1"
 	"knative.dev/serving/pkg/autoscaler/config/autoscalerconfig"
 	"knative.dev/serving/pkg/deployment"
+	"knative.dev/serving/pkg/networking"
 	"knative.dev/serving/pkg/queue"
 
+	_ "knative.dev/pkg/metrics/testing"
 	. "knative.dev/serving/pkg/testing/v1"
 )
 
@@ -53,14 +53,9 @@ var (
 	sidecarContainerName2        = "sidecar-container-2"
 	sidecarIstioInjectAnnotation = "sidecar.istio.io/inject"
 	defaultServingContainer      = &corev1.Container{
-		Name:  servingContainerName,
-		Image: "busybox",
-		Ports: buildContainerPorts(v1.DefaultUserPort),
-		VolumeMounts: []corev1.VolumeMount{{
-			Name:        varLogVolume.Name,
-			MountPath:   "/var/log",
-			SubPathExpr: "$(K_INTERNAL_POD_NAMESPACE)_$(K_INTERNAL_POD_NAME)_" + servingContainerName,
-		}},
+		Name:                     servingContainerName,
+		Image:                    "busybox",
+		Ports:                    buildContainerPorts(v1.DefaultUserPort),
 		Lifecycle:                userLifecycle,
 		TerminationMessagePolicy: corev1.TerminationMessageFallbackToLogsOnError,
 		Stdin:                    false,
@@ -75,12 +70,6 @@ var (
 			Name: "K_CONFIGURATION",
 		}, {
 			Name: "K_SERVICE",
-		}, {
-			Name:      "K_INTERNAL_POD_NAME",
-			ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.name"}},
-		}, {
-			Name:      "K_INTERNAL_POD_NAMESPACE",
-			ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.namespace"}},
 		}},
 	}
 
@@ -88,14 +77,28 @@ var (
 		Name:      QueueContainerName,
 		Resources: createQueueResources(&deploymentConfig, make(map[string]string), &corev1.Container{}),
 		Ports:     append(queueNonServingPorts, queueHTTPPort),
-		ReadinessProbe: &corev1.Probe{
+		StartupProbe: &corev1.Probe{
 			Handler: corev1.Handler{
 				Exec: &corev1.ExecAction{
-					Command: []string{"/ko-app/queue", "-probe-period", "0"},
+					Command: []string{"/ko-app/queue", "-probe-timeout", "1h34m38s"},
 				},
 			},
-			PeriodSeconds:  10,
-			TimeoutSeconds: 10,
+			PeriodSeconds:    1,
+			FailureThreshold: 1,
+			SuccessThreshold: 1,
+			TimeoutSeconds:   5678,
+		},
+		ReadinessProbe: &corev1.Probe{
+			Handler: corev1.Handler{
+				HTTPGet: &corev1.HTTPGetAction{
+					Port: intstr.FromInt(int(queueHTTPPort.ContainerPort)),
+					HTTPHeaders: []corev1.HTTPHeader{{
+						Name:  network.ProbeHeaderName,
+						Value: queue.Name,
+					}},
+				},
+			},
+			PeriodSeconds: 1,
 		},
 		SecurityContext: queueSecurityContext,
 		Env: []corev1.EnvVar{{
@@ -183,8 +186,8 @@ var (
 	}
 
 	defaultPodSpec = &corev1.PodSpec{
-		Volumes:                       []corev1.Volume{varLogVolume},
 		TerminationGracePeriodSeconds: refInt64(45),
+		EnableServiceLinks:            ptr.Bool(false),
 	}
 
 	defaultDeployment = &appsv1.Deployment{
@@ -231,13 +234,8 @@ var (
 
 func defaultSidecarContainer(containerName string) *corev1.Container {
 	return &corev1.Container{
-		Name:  containerName,
-		Image: "ubuntu",
-		VolumeMounts: []corev1.VolumeMount{{
-			Name:        varLogVolume.Name,
-			MountPath:   "/var/log",
-			SubPathExpr: "$(K_INTERNAL_POD_NAMESPACE)_$(K_INTERNAL_POD_NAME)_" + containerName,
-		}},
+		Name:                     containerName,
+		Image:                    "ubuntu",
 		Lifecycle:                userLifecycle,
 		TerminationMessagePolicy: corev1.TerminationMessageFallbackToLogsOnError,
 		Stdin:                    false,
@@ -249,12 +247,6 @@ func defaultSidecarContainer(containerName string) *corev1.Container {
 			Name: "K_CONFIGURATION",
 		}, {
 			Name: "K_SERVICE",
-		}, {
-			Name:      "K_INTERNAL_POD_NAME",
-			ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.name"}},
-		}, {
-			Name:      "K_INTERNAL_POD_NAMESPACE",
-			ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.namespace"}},
 		}},
 	}
 }
@@ -477,6 +469,7 @@ func TestMakePodSpec(t *testing.T) {
 		name string
 		rev  *v1.Revision
 		oc   metrics.ObservabilityConfig
+		dc   *apicfg.Defaults
 		want *corev1.PodSpec
 	}{{
 		name: "user-defined user port, queue proxy have PORT env",
@@ -560,6 +553,60 @@ func TestMakePodSpec(t *testing.T) {
 					},
 				},
 			})),
+	}, {
+		name: "explicit true service links",
+		rev: revision("bar", "foo",
+			withContainers([]corev1.Container{{
+				Name:           servingContainerName,
+				Image:          "busybox",
+				ReadinessProbe: withTCPReadinessProbe(v1.DefaultUserPort),
+			}}),
+			WithContainerStatuses([]v1.ContainerStatus{{
+				ImageDigest: "busybox@sha256:deadbeef",
+			}}),
+		),
+		want: podSpec(
+			[]corev1.Container{
+				servingContainer(func(container *corev1.Container) {
+					container.Image = "busybox@sha256:deadbeef"
+				}),
+				queueContainer(),
+			}, func(p *corev1.PodSpec) {
+				p.EnableServiceLinks = ptr.Bool(true)
+			}),
+		dc: func() *apicfg.Defaults {
+			d, _ := apicfg.NewDefaultsConfigFromMap(map[string]string{
+				"enable-service-links": "true",
+			})
+			return d
+		}(),
+	}, {
+		name: "explicit default service links",
+		rev: revision("bar", "foo",
+			withContainers([]corev1.Container{{
+				Name:           servingContainerName,
+				Image:          "busybox",
+				ReadinessProbe: withTCPReadinessProbe(v1.DefaultUserPort),
+			}}),
+			WithContainerStatuses([]v1.ContainerStatus{{
+				ImageDigest: "busybox@sha256:deadbeef",
+			}}),
+		),
+		want: podSpec(
+			[]corev1.Container{
+				servingContainer(func(container *corev1.Container) {
+					container.Image = "busybox@sha256:deadbeef"
+				}),
+				queueContainer(),
+			}, func(p *corev1.PodSpec) {
+				p.EnableServiceLinks = nil
+			}),
+		dc: func() *apicfg.Defaults {
+			d, _ := apicfg.NewDefaultsConfigFromMap(map[string]string{
+				"enable-service-links": "default",
+			})
+			return d
+		}(),
 	}, {
 		name: "concurrency=1 no owner",
 		rev: revision("bar", "foo",
@@ -939,7 +986,7 @@ func TestMakePodSpec(t *testing.T) {
 				),
 			}),
 	}, {
-		name: "propertes allowed by the webhook are passed through",
+		name: "properties allowed by the webhook are passed through",
 		rev: revision("bar", "foo",
 			withContainers([]corev1.Container{{
 				Name:  servingContainerName,
@@ -968,16 +1015,84 @@ func TestMakePodSpec(t *testing.T) {
 				p.EnableServiceLinks = ptr.Bool(false)
 			},
 		),
+	}, {
+		name: "var-log collection enabled",
+		oc: metrics.ObservabilityConfig{
+			EnableVarLogCollection: true,
+		},
+		rev: revision("bar", "foo",
+			withContainers([]corev1.Container{{
+				Name:           servingContainerName,
+				Image:          "busybox",
+				ReadinessProbe: withTCPReadinessProbe(v1.DefaultUserPort),
+				Ports:          buildContainerPorts(v1.DefaultUserPort),
+			}, {
+				Name:  sidecarContainerName,
+				Image: "ubuntu",
+			}}),
+			WithContainerStatuses([]v1.ContainerStatus{{
+				ImageDigest: "busybox@sha256:deadbeef",
+			}, {
+				ImageDigest: "ubuntu@sha256:deadbeef",
+			}}),
+		),
+		want: podSpec(
+			[]corev1.Container{
+				servingContainer(func(container *corev1.Container) {
+					container.Image = "busybox@sha256:deadbeef"
+					container.VolumeMounts = []corev1.VolumeMount{{
+						Name:        varLogVolume.Name,
+						MountPath:   "/var/log",
+						SubPathExpr: "$(K_INTERNAL_POD_NAMESPACE)_$(K_INTERNAL_POD_NAME)_" + servingContainerName,
+					}}
+					container.Env = append(container.Env,
+						corev1.EnvVar{
+							Name:      "K_INTERNAL_POD_NAME",
+							ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.name"}},
+						},
+						corev1.EnvVar{
+							Name:      "K_INTERNAL_POD_NAMESPACE",
+							ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.namespace"}},
+						})
+				}),
+				sidecarContainer(sidecarContainerName, func(c *corev1.Container) {
+					c.Image = "ubuntu@sha256:deadbeef"
+					c.VolumeMounts = []corev1.VolumeMount{{
+						Name:        varLogVolume.Name,
+						MountPath:   "/var/log",
+						SubPathExpr: "$(K_INTERNAL_POD_NAMESPACE)_$(K_INTERNAL_POD_NAME)_" + sidecarContainerName,
+					}}
+					c.Env = append(c.Env,
+						corev1.EnvVar{
+							Name:      "K_INTERNAL_POD_NAME",
+							ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.name"}},
+						},
+						corev1.EnvVar{
+							Name:      "K_INTERNAL_POD_NAMESPACE",
+							ValueFrom: &corev1.EnvVarSource{FieldRef: &corev1.ObjectFieldSelector{FieldPath: "metadata.namespace"}},
+						})
+				}),
+				queueContainer(
+					withEnvVar("SERVING_READINESS_PROBE", `{"tcpSocket":{"port":8080,"host":"127.0.0.1"}}`),
+				),
+			},
+			withAppendedVolumes(varLogVolume),
+		),
 	}}
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			got, err := makePodSpec(test.rev, &logConfig, &traceConfig, &test.oc, &deploymentConfig)
+			cfg := (&revCfg).DeepCopy()
+			cfg.Observability = &test.oc
+			if test.dc != nil {
+				cfg.Defaults = test.dc
+			}
+			got, err := makePodSpec(test.rev, cfg)
 			if err != nil {
 				t.Fatal("makePodSpec returned error:", err)
 			}
 			if diff := cmp.Diff(test.want, got, quantityComparer); diff != "" {
-				t.Errorf("makePodSpec (-want, +got) = %v", diff)
+				t.Errorf("makePodSpec (-want, +got) =\n%s", diff)
 			}
 		})
 	}
@@ -988,8 +1103,7 @@ var quantityComparer = cmp.Comparer(func(x, y resource.Quantity) bool {
 })
 
 func TestMissingProbeError(t *testing.T) {
-	if _, err := MakeDeployment(revision("bar", "foo"), &logConfig, &traceConfig,
-		&network.Config{}, &obsConfig, &deploymentConfig, &asConfig); err == nil {
+	if _, err := MakeDeployment(revision("bar", "foo"), &revCfg); err == nil {
 		t.Error("expected error from MakeDeployment")
 	}
 }
@@ -1125,21 +1239,23 @@ func TestMakeDeployment(t *testing.T) {
 				test.acMutator(ac)
 			}
 			// Tested above so that we can rely on it here for brevity.
-			podSpec, err := makePodSpec(test.rev, &logConfig, &traceConfig,
-				&obsConfig, &deploymentConfig)
+			cfg := (&revCfg).DeepCopy()
+			cfg.Autoscaler = ac
+			cfg.Deployment = &test.dc
+			podSpec, err := makePodSpec(test.rev, cfg)
 			if err != nil {
 				t.Fatal("makePodSpec returned error:", err)
 			}
 			if test.want != nil {
 				test.want.Spec.Template.Spec = *podSpec
 			}
-			got, err := MakeDeployment(test.rev, &logConfig, &traceConfig,
-				&network.Config{}, &obsConfig, &test.dc, ac)
+			// Copy to override
+			got, err := MakeDeployment(test.rev, cfg)
 			if err != nil {
 				t.Fatal("Got unexpected error:", err)
 			}
 			if diff := cmp.Diff(test.want, got, quantityComparer); diff != "" {
-				t.Error("MakeDeployment (-want, +got) =", diff)
+				t.Errorf("MakeDeployment (-want, +got) =\n%s", diff)
 			}
 		})
 	}
